"use client";

import Image from "next/image";
import { useRef } from "react";

import { motion, useScroll, useTransform } from "framer-motion";

import {
	BreadcrumbItem,
	CustomBreadcrumb,
} from "@/components/common/breadcrumb";
import { ContentLines } from "@/components/shared/content-lines";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";

export default function PageBreadcrump({
	locale,
	subtitle,
	title,
	breadcrumbItems,
	backgroundUrl,
}: {
	locale: Locale;
	subtitle: Record<Locale, string>;
	title: Record<Locale, string>;
	breadcrumbItems: BreadcrumbItem[];
	backgroundUrl?: string;
}): JSX.Element {
	const container = useRef<HTMLDivElement | null>(null);

	const { scrollYProgress } = useScroll({
		target: container,
		offset: ["start end", "end start"],
	});

	const y = useTransform(scrollYProgress, [0, 1], ["-10%", "10%"]);
	const isRTL = locale === "ar";

	return (
		<div
			ref={container}
			className="relative flex h-[323px] items-center justify-center overflow-hidden"
			style={{ clipPath: "polygon(0% 0, 100% 0%, 100% 100%, 0 100%)" }}
		>
			{/* Content Container */}
			<div className="container relative z-50 px-4 sm:px-4 md:px-1 lg:px-16">
				<div className="mt-12 flex flex-col">
					{/* Main Content */}
					<div className="flex h-full min-h-[125px] w-full flex-1 flex-col justify-between">
						<ContentLines
							title={subtitle?.[locale]}
							underlineColor="custom-primary-accent"
							textColor="text-white"
							padding="none"
						/>

						<div className="flex flex-col items-stretch justify-between md:flex-row md:items-end">
							<p
								className={cn(
									"text-[32px] font-normal text-white md:text-[48px]",
									isRTL && "text-right"
								)}
							>
								{title?.[locale]}
							</p>

							{/* Breadcrumb  */}
							<div
								className={cn("flex", isRTL ? "justify-end" : "justify-start")}
							>
								<CustomBreadcrumb items={breadcrumbItems} locale={locale} />
							</div>
						</div>
					</div>
				</div>
			</div>

			<div className="fixed left-0 top-[-10vh] h-[120vh] w-full">
				<motion.div style={{ y }} className="relative h-full w-full">
					<Image
						src={backgroundUrl ? backgroundUrl : "/heros/account.png"}
						fill
						alt="image"
						style={{ objectFit: "cover", zIndex: 10000 }}
					/>
					<div className="absolute inset-0 z-[10001] bg-[#0D0D0D99]" />
				</motion.div>
			</div>
		</div>
	);
}
